# Table of Contents

- [microservice-discovery-in-your-ci-cd-pipeline](<./microservice-discovery-in-your-ci-cd-pipeline.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Microservice Discovery in Your CI/CD Pipeline](<./Microservice-Discovery-in-Your-CICD-Pipeline.md>)
  - [Overview](<./Microservice-Discovery-in-Your-CICD-Pipeline/Overview.md>)
  - [Prerequisites](<./Microservice-Discovery-in-Your-CICD-Pipeline/Prerequisites.md>)
  - [Step 1: Create a Manifest File](<./Microservice-Discovery-in-Your-CICD-Pipeline/Step-1-Create-a-Manifest-File.md>)
  - [Step 2: Commit the Manifest File](<./Microservice-Discovery-in-Your-CICD-Pipeline/Step-2-Commit-the-Manifest-File.md>)
  - [Step 3: Generate a Software Bill of Materials (SBOM)](<./Microservice-Discovery-in-Your-CICD-Pipeline/Step-3-Generate-a-Software-Bill-of-Materials-SBOM.md>)
  - [Step 4: Upload the Manifest File](<./Microservice-Discovery-in-Your-CICD-Pipeline/Step-4-Upload-the-Manifest-File.md>)
  - [Step 5: Configure Your CI/CD Pipeline](<./Microservice-Discovery-in-Your-CICD-Pipeline/Step-5-Configure-Your-CICD-Pipeline.md>)
  - [Best Practices](<./Microservice-Discovery-in-Your-CICD-Pipeline/Best-Practices.md>)
  - [Was this page helpful?](<./Microservice-Discovery-in-Your-CICD-Pipeline/Was-this-page-helpful.md>)
